<img width="2000" height="1024" alt="irlpdf banner" src="https://github.com/user-attachments/assets/fdf65401-2637-47cf-ae89-b7f01e54422c" />

### irlpdf

irlpdf (i really love pdf) is a cli application 
that lets you alter pdfs. Perform actions like Compress, Split, Merge and other common pdf related operations without needing to search on the internet

current version (v0.1.0) is not stable and can contain bugs, majority of which will be fixed over the next few releases.

### utilities 

- compress a pdf
- merge multiple pdfs
- remove pages from a pdf
- stats of a pdf
- encrypt a pdf
- decrypt a pdf

to learn about commands use the man command as `irlpdf man help`

Docs and Windows/Linux distributions to be put out soon
